@@ -1,5 +1,4 @@
-if (require("testthat") && require("insight")) {
-  library(lme4)
+if (require("testthat") && require("insight") && require("lme4")) {
   data(mtcars)
   data(sleepstudy)
 
@@ -7,8 +6,7 @@ if (require("testthat") && require("insight")) {
   m2 <- lm(mpg ~ gear, data = mtcars)
   m3 <- lmer(Reaction ~ 1 + (Days | Subject), data = sleepstudy)
   m4 <- lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy)
-  m5 <-
-    suppressWarnings(lmer(Reaction ~ 0 + (Days | Subject), data = sleepstudy))
+  m5 <- suppressWarnings(lmer(Reaction ~ 0 + (Days | Subject), data = sleepstudy))
 
   test_that("is_nullmodel", {
     expect_true(is_nullmodel(m1))
