@@ -2,20 +2,11 @@
 
 if (.runThisTest || Sys.getenv("USER") == "travis") {
   if (require("testthat") && require("insight") && require("plm")) {
-    context("insight, model_info")
-
     data(Crime)
-    m1 <-
-      plm(
-        lcrmrte ~ lprbarr + factor(year) |
-          . - lprbarr + lmix,
-        data = Crime,
-        model = "random"
-      )
+    m1 <- plm(lcrmrte ~ lprbarr + factor(year) | . - lprbarr + lmix, data = Crime, model = "random")
 
     # data
     set.seed(123)
-    library(plm)
     data("Produc", package = "plm")
 
     # model
@@ -74,6 +65,12 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
         colnames(get_data(m1)),
         c("lcrmrte", "lprbarr", "year", "lmix")
       )
+
+      expect_equal(nrow(get_data(m2)), 816)
+      expect_equal(
+        colnames(get_data(m2)),
+        c("gsp", "pcap", "pc", "emp", "unemp", "state", "year")
+      )
     })
 
     test_that("find_formula", {
@@ -83,7 +80,8 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
         list(
           conditional = as.formula("lcrmrte ~ lprbarr + factor(year)"),
           instruments = as.formula("~-lprbarr + lmix")
-        )
+        ),
+        ignore_attr = TRUE
       )
     })
 
